#    
#Hello bill,
#
#We are happy to announce that your request to gain access to the Untappd API has been approved!
#
#Use your API key, listed below, to authenticate with our service so we know who you are. Please do not share your keys with anyone. 
#
#Client ID: 5F00B75F1F5D9606FEF91E8E7AEA442EF3A404AD
#Client Secret: BD9DAB30E0D69E9157FE5252C3E1773D7694665F 
#To get started here are few important links:
#
#    API Documentation V4: http://untappd.com/api/docs/v4
#    API Explorer (V4): http://untappd.com/api/explorer?v=4
#    Some important notes:
#
#        With our V4, all calls are over OAuth. If you authenticate, you user has 100 calls per hour. If you do not, your rate limit is applied to your API token.
#        We are always looking to improve our API both in documentation and feature requests. If you have a suggestions, please send an email to greg@untappd.com.
#        If you are using the Untappd API for something cool, let us know! We want to showcase it!
#        Make sure that you are following the terms of use for the API at http://untappd.com/terms/api
#        If you have any questions feel free to reach out to Greg at greg@untappd.com
#
#        Thanks again for your support of Untappd!
#
#
#        Cheers,
#        Untappd team

# In [102]: r = requests.get("https://api.untappd.com/v4/user/checkins/llimllib?client_id=5F00B75F1F5D9606FEF91E8E7AEA442EF3A404AD&client_secret=BD9DAB30E0D69E9157FE5252C3E1773D7694665F")

# In [103]: r.json()["response"]["checkins"]["items"][0]
